@@ -22,11 +22,14 @@ The S3 bucket is configured as below
   * Deep Archive 180 days
   * Expiry after 365 days
 
-## Planned Features
+The CodeBuild projects are configured as below
 
 * Logging to CloudWatch
 
   * Encryption using customer-managed KMS key
+
+## Planned Features
+
 * Notifications to SNS about uploaded objects
 * Tagging of created AWS resources
 
@@ -59,6 +62,7 @@ from typeguard import check_type
 
 from ._jsii import *
 
+import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
 import constructs as _constructs_77d1e7e8
 
 
@@ -93,6 +97,24 @@ class Archiver(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
+    @builtins.property
+    @jsii.member(jsii_name="logGroup")
+    def log_group(self) -> _aws_cdk_aws_logs_ceddda9d.LogGroup:
+        '''(experimental) Log group used by the CodeBuild projects.
+
+        :stability: experimental
+        :memberof: Archiver
+        :type: {LogGroup}
+        '''
+        return typing.cast(_aws_cdk_aws_logs_ceddda9d.LogGroup, jsii.get(self, "logGroup"))
+
+    @log_group.setter
+    def log_group(self, value: _aws_cdk_aws_logs_ceddda9d.LogGroup) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__9bb1a921963ed134fd11e5243da72c17693bf46b95bcb2787c98f86c2344cac1)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "logGroup", value)
+
     @builtins.property
     @jsii.member(jsii_name="props")
     def props(self) -> "ArchiverProperties":
@@ -273,6 +295,12 @@ def _typecheckingstub__59b1d445ea6a4ea2b344c5e83eb14b7e5d57e243d55dbad607605e1e2
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__9bb1a921963ed134fd11e5243da72c17693bf46b95bcb2787c98f86c2344cac1(
+    value: _aws_cdk_aws_logs_ceddda9d.LogGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__fb1dff6681014d6e509e01d6b12c3974e4810c8d1a67b368174954a280d668f6(
     value: ArchiverProperties,
 ) -> None:
